package compiler

import (
	"io"

	"git.urbach.dev/cli/q/src/config"
	"git.urbach.dev/cli/q/src/dll"
	"git.urbach.dev/cli/q/src/elf"
	"git.urbach.dev/cli/q/src/macho"
	"git.urbach.dev/cli/q/src/pe"
	"git.urbach.dev/cli/q/src/wasm"
)

// Write writes the executable to the given writer.
func (r *Result) Write(writer io.WriteSeeker) {
	write(writer, r.Code, r.Data, r.DLLs)
}

// write writes an executable file to the given writer.
func write(writer io.WriteSeeker, code []byte, data []byte, dlls dll.List) {
	switch config.TargetOS {
	case config.Linux:
		elf.Write(writer, code, data)
	case config.Mac:
		macho.Write(writer, code, data)
	case config.Web:
		wasm.Write(writer, code, data)
	case config.Windows:
		pe.Write(writer, code, data, dlls)
	}
}
